@@ -7,6 +7,7 @@ async def gather(
     hub,
     profile: Dict[str, Any],
     providers: List[str],
+    hard_fail: bool = False,
 ):
     """
     Get the metadata for the given profile, which probably comes from an idem state's ctx.acct
@@ -14,6 +15,7 @@ async def gather(
     :param hub:
     :param profile: A dictionary containing login credentials for the provider
     :param providers: A list of providers that may be related to this sub
+    :param hard_fail: Raise exceptions instead of catching them
     """
     for provider in providers:
         if provider in hub.acct.metadata:
@@ -23,6 +25,8 @@ async def gather(
                 hub.log.error(
                     f"Error gathering metadata from {provider}: {e.__class__.__name__}: {e}"
                 )
+                if hard_fail:
+                    raise
     else:
         for provider in providers:
             hub.log.debug(
